@@ -17,15 +17,15 @@ rect.fill_opacity(0.25)
 rect.rectangle(23, 81, 107+23, 139+81)
 rect.draw(img)
 
-img.write('crop_before.jpg')
+img.write('crop_before.png')
 
 # Create a image to use as a background for
 # the "after" image.
-bg = Magick::Image.new(img.columns, img.rows)
+bg = Magick::Image.new(img.columns, img.rows) {self.background_color="none"}
 
 # Composite the the "after" (chopped) image on the background
 bg = bg.composite(chopped, 23, 81, Magick::OverCompositeOp)
 
-bg.write('crop_after.jpg')
+bg.write('crop_after.png')
 
 exit
